/****************************************************************
 *								*
 * Copyright (c) 2001-2019 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef MUCREGINI_INCLUDED
#define MUCREGINI_INCLUDED

#include "gdsroot.h"

void mucregini(block_id blk_init_size);

#endif /* MUCREGINI_INCLUDED */
